var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { h } from "@stencil/core";
import { extractHtmlButtonProps, extractHtmlLinkProps } from "../../utils/properties.utils";
import { Slot } from "../../utils/slot";
/**
 * Buttons allow users to interact with the product and trigger actions. They can be of different sizes, colors and status
 * In terms of accessibility, be mindful of people using assistive technologies: don’t use links instead of buttons to trigger actions.
 *
 * @slot custom-icon - Button custom icon
 *
 * @since 0.1.0-next.1
 * @lastmodified 0.1.0-next.1
 */
export class Button {
    constructor() {
        this.rootClass = 'nj-btn';
        this.as = 'button';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
            [`${this.rootClass}--${this.emphasis}`]: !!this.emphasis,
            [`${this.rootClass}--is-loading`]: !!this.isLoading,
        };
    }
    get elementProps() {
        return this.as === 'a' ? extractHtmlLinkProps(this) : extractHtmlButtonProps(this);
    }
    render() {
        var _a;
        const Element = this.as;
        (_a = this.customIcon) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.rootClass}__icon`);
        return (h(Element, Object.assign({ key: '70c7eddd496596fc21fe1ba4aa55d8c63060b3b4', class: this.classes }, this.elementProps), this.isLoading && h("nj-spinner", { key: 'a60b2e45a615371e45fe909240769f8503be5f5d' }), this.icon && !this.customIcon && !this.isLoading && h("nj-icon", { key: '625a5d78e5961d54844470f053de2b5a022e1a6f', class: `${this.rootClass}__icon`, name: this.icon }), h("slot", { key: 'f3bdf3c82a537d7edf538379b8bd2abe058f7db3', name: "custom-icon" }), h("slot", { key: 'a7ce759843dda76efaa01ca90242803875dcec39' })));
    }
    static get is() { return "nj-button"; }
    static get styles() { return "nj-button { display: contents }"; }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['as']",
                    "resolved": "\"a\" | \"button\"",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The element tag to render"
                },
                "getter": false,
                "setter": false,
                "attribute": "as",
                "reflect": false,
                "defaultValue": "'button'"
            },
            "emphasis": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['emphasis']",
                    "resolved": "\"bold\" | \"minimal\" | \"subtle\" | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The button emphasis"
                },
                "getter": false,
                "setter": false,
                "attribute": "emphasis",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['variant']",
                    "resolved": "\"ai\" | \"destructive\" | \"inverse\" | \"primary\" | \"secondary\" | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The button variant"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['scale']",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\" | \"xs\" | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The button size"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['icon']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The button icon name"
                },
                "getter": false,
                "setter": false,
                "attribute": "icon",
                "reflect": false
            },
            "isLoading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['isLoading']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether button is loading or not"
                },
                "getter": false,
                "setter": false,
                "attribute": "is-loading",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['href']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['rel']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['target']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "download": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['download']",
                    "resolved": "boolean | string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "download",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['type']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            },
            "form": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['form']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "form",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['name']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['value']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/button/button.tsx",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
__decorate([
    Slot('custom-icon')
], Button.prototype, "customIcon", void 0);
//# sourceMappingURL=button.js.map
