import { BUTTON_EMPHASIS, BUTTON_SCALES, BUTTON_VARIANTS } from "@engie-group/fluid-types";
// Styles constants for better readability
const STYLES = {
    wrapper: 'display: flex; flex-wrap: wrap; gap: var(--nj-semantic-size-spacing-8)',
    variantWrapper: 'display: flex; flex-wrap: wrap;',
    buttonContainer: (variant) => `
    padding: 1rem; 
    display: flex; 
    gap: var(--nj-semantic-size-spacing-8);
    ${variant === 'inverse' ? 'background-color: var(--nj-semantic-color-background-neutral-spotlight-default);' : ''}
  `,
    emphasisContainer: 'display: flex; flex-direction: column; gap: var(--nj-semantic-size-spacing-8);',
};
// Variations of buttons to display
const BUTTON_VARIATIONS = ['none', 'icon', 'disabled', 'loading'];
// Helper function to generate attributes for a button
const getButtonAttributes = (scale, emphasis, variant, variation) => {
    const attributes = [
        `scale="${scale}"`,
        `emphasis="${emphasis}"`,
        `variant="${variant}"`,
        'type="button"'
    ];
    if (variation === 'disabled')
        attributes.push('disabled');
    if (variation === 'loading')
        attributes.push('is-loading');
    return attributes.join(' ');
};
// Helper function to generate button content
const getButtonContent = (variation) => {
    const iconMarkup = variation === 'icon'
        ? '<span class="material-icons nj-icon-material nj-btn__icon" aria-hidden="true">dashboard</span> '
        : '';
    return `${iconMarkup}Button`;
};
// Generate the HTML fragment
export const fragment = `
<div style="${STYLES.wrapper}">
  ${BUTTON_VARIATIONS.map(variation => `
    <div style="${STYLES.variantWrapper}">
      ${BUTTON_VARIANTS.map(variant => `
        <div style="${STYLES.buttonContainer(variant)}">
          ${BUTTON_SCALES.map(scale => `
            <div style="${STYLES.emphasisContainer}">
              ${BUTTON_EMPHASIS.map(emphasis => `
                <nj-button ${getButtonAttributes(scale, emphasis, variant, variation)}>
                  ${getButtonContent(variation)}
                </nj-button>
              `).join('')}
            </div>
          `).join('')}
        </div>
      `).join('')}
    </div>
  `).join('')}
</div>`;
//# sourceMappingURL=fragment.js.map
