import { h, Host } from "@stencil/core";
import { useId } from "../../utils/id";
import { hasSlot } from "../../utils/slot";
/**
 * A checkbox is an input control that allows the user to give a feedback by choosing several items from a list of options.
 *
 * @since 0.1.0-next.1
 * @lastmodified 0.1.0-next.1
 */
export class Checkbox {
    constructor() {
        this.rootClass = 'nj-checkbox';
        this.handleChange = (event) => {
            const input = event.target;
            this.checked = input.checked;
            this.checkedChange.emit(this.checked);
            const newIndeterminateState = input.indeterminate;
            if (this.indeterminate !== newIndeterminateState) {
                this.indeterminate = newIndeterminateState;
                this.indeterminateChange.emit(this.indeterminate);
            }
        };
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
            [`${this.rootClass}--${this.subscriptVariant}`]: !!this.subscriptVariant,
        };
    }
    render() {
        let subscriptId;
        if (this.subscript) {
            subscriptId = `linked-subscript-message-${useId(this.inputId)}`;
        }
        const input = h("input", { key: '3139dada067fcc54d88cc93b5f14676f501b1094', type: "checkbox", id: this.inputId, name: this.name, value: this.value, checked: this.checked, disabled: this.disabled, required: this.required, "aria-describedby": subscriptId, "aria-invalid": this.invalid ? 'true' : undefined, onChange: (event) => this.handleChange(event) });
        return (h(Host, { key: '6a52d07d19286395ab4402af3a46415eb3a7c964', class: this.classes }, hasSlot(this.element) ?
            h("label", null, input, h("span", { class: `${this.rootClass}__label` }, h("slot", null), this.required && (h("span", { "aria-hidden": "true", class: "nj-checkbox__required" }, "*")))) : input, this.subscript && (h("div", { key: 'e30110566f69177a75a36374c95aaf85a9f4e2a2', class: "nj-checkbox__subscript", id: subscriptId }, this.subscriptVariant === 'success' && h("nj-icon", { key: '3e05d6a314d0f85cae461493605d3ac807d58cbc', name: "check", variant: "inherit" }), this.subscriptVariant === 'error' && h("nj-icon", { key: 'c7c6b6ed59a62e50d957a879df63d1de84987a36', name: "warning", variant: "inherit" }), this.subscript))));
    }
    componentDidRender() {
        const input = this.element.querySelector('input');
        if (input && this.indeterminate) {
            input.indeterminate = true;
        }
    }
    static get is() { return "nj-checkbox"; }
    static get properties() {
        return {
            "inputId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "type",
                            "text": "{string}"
                        }],
                    "text": "Represents the identifier for the input element.\nThis optional variable allows you to specify a unique identifier\nfor referencing or interacting with the input element."
                },
                "getter": false,
                "setter": false,
                "attribute": "input-id",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Name of the form control. Submitted with the form as part of a name/value pair"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The value of the checkbox when checked."
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['scale']",
                    "resolved": "\"lg\" | \"md\" | \"xl\" | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Defines the size of the checkbox component.\n\nPossible values:\n- 'md': Medium size (default).\n- 'lg': Large size, for enhanced visibility and accessibility.\n- 'xl': Extra-large size, providing maximum visibility and ease of interaction."
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "subscript": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['subscript']",
                    "resolved": "string | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Text content displayed as subscript below the checkbox,\nused for additional labels, instructions, or feedback messages."
                },
                "getter": false,
                "setter": false,
                "attribute": "subscript",
                "reflect": false
            },
            "subscriptVariant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['subscriptVariant']",
                    "resolved": "\"error\" | \"success\" | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Defines the visual variant of the subscript message, indicating\na specific status or state.\n\nPossible values:\n- 'error': Indicates an error or issue with user input or selection.\n- 'success': Indicates successful input validation or positive feedback.\n\nIf not specified, defaults to a neutral display without special styling."
                },
                "getter": false,
                "setter": false,
                "attribute": "subscript-variant",
                "reflect": false
            },
            "checked": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "CheckboxProperties['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox component is checked"
                },
                "getter": false,
                "setter": false,
                "attribute": "checked",
                "reflect": true
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox component is required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": true
            },
            "indeterminate": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "CheckboxProperties['indeterminate']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox component is indeterminate"
                },
                "getter": false,
                "setter": false,
                "attribute": "indeterminate",
                "reflect": true
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox component is disabled"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": true
            },
            "invalid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "CheckboxProperties['invalid']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "CheckboxProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::CheckboxProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the checkbox component is invalid"
                },
                "getter": false,
                "setter": false,
                "attribute": "invalid",
                "reflect": true
            }
        };
    }
    static get events() {
        return [{
                "method": "checkedChange",
                "name": "nj-checked-change",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emits a boolean value indicating the change in the \"checked\" state."
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }, {
                "method": "indeterminateChange",
                "name": "nj-indeterminate-change",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Emits an event whenever the indeterminate state of the checkbox changes."
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "element"; }
}
//# sourceMappingURL=checkbox.js.map
