import { h, Host } from "@stencil/core";
/**
 * A divider is a component used to separate two elements at the same level
 *
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.3
 */
export class Divider {
    constructor() {
        this.rootClass = 'nj-divider';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
            [`${this.rootClass}--vertical`]: !!this.vertical,
        };
    }
    render() {
        return h(Host, { key: 'a995b88d02ad7d29bc44949cfcf2f88c10315ebf', class: this.classes, role: "separator", "aria-orientation": this.vertical ? 'vertical' : undefined });
    }
    static get is() { return "nj-divider"; }
    static get properties() {
        return {
            "vertical": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "DividerProperties['vertical']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "DividerProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::DividerProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the divider is vertical or horizontal"
                },
                "getter": false,
                "setter": false,
                "attribute": "vertical",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "DividerProperties['scale']",
                    "resolved": "\"2xl\" | \"2xs\" | \"3xl\" | \"lg\" | \"md\" | \"none\" | \"sm\" | \"xl\" | \"xs\" | undefined",
                    "references": {
                        "DividerProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::DividerProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Spacing around the divider"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=divider.js.map
