import { h } from "@stencil/core";
/**
 * Footer is mainly used for links and legal information.
 *
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.0
 */
export class Footer {
    constructor() {
        this.RESPONSIVE_CSS_VAR = '--nj-footer-responsive-mode';
        this.handleResize = () => {
            if (this.resizeTimeout) {
                clearTimeout(this.resizeTimeout);
            }
            this.resizeTimeout = setTimeout(() => this.updateMode(), 200);
        };
    }
    get classes() {
        return {
            'nj-footer': true,
            [`nj-footer--${this.variant}`]: !!this.variant && this.variant !== 'neutral',
            'nj-footer--mobile': this.responsiveMode === 'mobile',
        };
    }
    getCssVariable(varName) {
        return getComputedStyle(document.documentElement).getPropertyValue(varName).trim().replace(/"/g, '');
    }
    updateMode() {
        const newMode = this.getCssVariable(this.RESPONSIVE_CSS_VAR);
        if (newMode !== this.responsiveMode) {
            this.responsiveMode = newMode;
        }
    }
    componentWillLoad() {
        this.updateMode();
        window.addEventListener('resize', this.handleResize);
    }
    disconnectedCallback() {
        window.removeEventListener('resize', this.handleResize);
        if (this.resizeTimeout) {
            clearTimeout(this.resizeTimeout);
        }
    }
    render() {
        return (h("div", { key: '12c689256152ef5b70b7d15764b46eb5811eef7b', class: this.classes }, h("slot", { key: '0cf63a401f9e957c41d9e783dedbcc0afa355f68' })));
    }
    static get is() { return "nj-footer"; }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "FooterProperties['variant']",
                    "resolved": "\"brand\" | \"neutral\" | undefined",
                    "references": {
                        "FooterProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::FooterProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Footer variant theme"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "resizeTimeout": {},
            "responsiveMode": {}
        };
    }
}
//# sourceMappingURL=footer.js.map
