import { h } from "@stencil/core";
/**
 * Links displayed in the footer component.
 *
 * @slot leading - Slot for the leading element of the footer item
 * @slot trailing - Slot for the trailing element of the footer item
 *
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.0
 */
export class FooterItem {
    get classes() {
        return {
            'nj-footer-item': true,
            [`nj-footer-item--padding-${this.padding}`]: !!this.padding,
        };
    }
    render() {
        return (h("nj-link", { key: 'f865e4181718ae8499cbf6b4c1c4f3cfeeb1adb9', class: this.classes, rel: this.rel, target: this.target, href: this.href, download: this.download, scale: this.scale, variant: "contextual" }, h("slot", { key: '5456d9d42bdcf08042e437dd4ad6eecc66e38c57', name: "leading" }), h("slot", { key: '89e9c55058b8b97509511ccb01c4f4e18791657d' }), h("slot", { key: '86d5a82f80ccce3c2a537898d0915f7899a96337', name: "trailing" })));
    }
    static get is() { return "nj-footer-item"; }
    static get styles() { return "nj-footer-item { display: contents }"; }
    static get properties() {
        return {
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The URL that the hyperlink points to."
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The relationship between the current document and the linked document"
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Specifies where to open the linked document"
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "download": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Specifies whether the linked document will have a download option when clicked.\nIf a string is provided, it will be used as the filename."
                },
                "getter": false,
                "setter": false,
                "attribute": "download",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "FooterItemProperties['scale']",
                    "resolved": "\"md\" | \"sm\" | undefined",
                    "references": {
                        "FooterItemProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::FooterItemProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The scale of the footer item. Impacts the size of the text."
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "padding": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "FooterItemProperties['padding']",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xs\" | undefined",
                    "references": {
                        "FooterItemProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::FooterItemProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Padding of the footer item. Impacts the size of the item."
                },
                "getter": false,
                "setter": false,
                "attribute": "padding",
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=footer-item.js.map
