import { Fragment, h } from "@stencil/core";
import { extractHtmlButtonProps, extractHtmlLinkProps } from "../../utils/properties.utils";
/**
 * Icon buttons are a variation of buttons. Use them only to trigger actions.
 *
 * @slot custom-icon - Replace icon with a custom element
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.3
 */
export class IconButton {
    constructor() {
        this.rootClass = 'nj-icon-btn';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
        };
    }
    get elementProps() {
        return this.as === 'a' ? extractHtmlLinkProps(this) : extractHtmlButtonProps(this);
    }
    render() {
        var _a;
        const Element = (_a = this.as) !== null && _a !== void 0 ? _a : 'a';
        return (h(Element, Object.assign({ key: 'eabc55fdb696242b0eb50cc6a1f35d02f553ce53', class: this.classes }, this.elementProps, { "aria-pressed": this.pressed, "aria-label": this.altLabel }), this.icon && (h(Fragment, { key: '979da70aeed743009c761e545c3803fd710ec555' }, h("nj-icon", { key: '243118c42fa4fc43ee012a2a54258fc55b0fb3bb', class: "nj-icon-btn__icon", name: this.icon }))), h("slot", { key: 'a09e35d2599d5a7b7fb74f41c1f601911f5f85e4', name: "custom-icon" })));
    }
    static get is() { return "nj-icon-button"; }
    static get styles() { return "nj-icon-button { display: contents }"; }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['as']",
                    "resolved": "\"a\" | \"button\" | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The element tag to render"
                },
                "getter": false,
                "setter": false,
                "attribute": "as",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['scale']",
                    "resolved": "\"2xs\" | \"lg\" | \"md\" | \"sm\" | \"xl\" | \"xs\" | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon button scale"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['icon']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon button material icon name (from https://material.io/resources/icons/?style=baseline)"
                },
                "getter": false,
                "setter": false,
                "attribute": "icon",
                "reflect": false
            },
            "altLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['altLabel']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon alternative label"
                },
                "getter": false,
                "setter": false,
                "attribute": "alt-label",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['variant']",
                    "resolved": "\"brand\" | \"destructive\" | \"inverse\" | \"primary\" | \"secondary\" | \"tertiary\" | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon button theme variant"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "pressed": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['pressed']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Indicates the current \"pressed\" state of a toggle button."
                },
                "getter": false,
                "setter": false,
                "attribute": "pressed",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['href']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['rel']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['target']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "download": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['download']",
                    "resolved": "boolean | string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "download",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['type']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            },
            "form": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['form']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "form",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['name']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconButtonProps['value']",
                    "resolved": "string | undefined",
                    "references": {
                        "IconButtonProps": {
                            "location": "import",
                            "path": "./types",
                            "id": "src/components/icon-button/types.ts::IconButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=icon-button.js.map
