import { ICON_ENGIE_PREFIX } from "@engie-group/fluid-types";
import { h, Host } from "@stencil/core";
/**
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.0
 */
export class Icon {
    constructor() {
        this.rootClass = 'nj-icon-material';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            'material-icons': true,
            [`${this.rootClass}--${this.variant === 'inherit' ? 'color-' : ''}${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale === 'inherit' ? 'size-' : ''}${this.scale}`]: !!this.scale,
            [`${this.rootClass}--engie`]: this.name.startsWith(ICON_ENGIE_PREFIX),
        };
    }
    render() {
        return (h(Host, { key: 'cf5457b4880a948df381eb37e0655b5c5f335baf', "aria-hidden": "true", class: this.classes }, this.name));
    }
    static get is() { return "nj-icon"; }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconProperties['variant']",
                    "resolved": "IconVariant | undefined",
                    "references": {
                        "IconProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::IconProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon variant theme"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconProperties['scale']",
                    "resolved": "\"2xl\" | \"2xs\" | \"3xl\" | \"4xl\" | \"5xl\" | \"6xl\" | \"inherit\" | \"lg\" | \"md\" | \"sm\" | \"xl\" | \"xs\" | undefined",
                    "references": {
                        "IconProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::IconProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Icon size"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IconProperties['name']",
                    "resolved": "string",
                    "references": {
                        "IconProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::IconProperties"
                        }
                    }
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Material icon name https://material.io/resources/icons/?style=baseline"
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=icon.js.map
