import { h, Host } from "@stencil/core";
import { hasSlot } from "../../utils/slot";
/**
 * @slot action - Optional inline message actions slot. You can pass any element (recommended `nj-link` or `nj-icon-button`).
 *
 * @since 0.1.0-next.1
 * @lastmodified 0.1.0-next.1
 */
export class InlineMessage {
    constructor() {
        this.rootClass = 'nj-inline-message';
        this.closable = false;
        this.onCloseHandler = () => {
            this.onClose.emit();
        };
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
            [`${this.rootClass}--action-position-${this.actionPosition}`]: !!this.actionPosition,
        };
    }
    render() {
        return (h(Host, { key: '669f002b95974d7a31fac5e03d1e5d68c9f54c5f', class: this.classes }, this.hasStatus && h("nj-status-indicator", { key: '2568dddd9ed6e64cb419071cc35ad1ee445d99f5', class: `${this.rootClass}__status` }), h("div", { key: '802284ddb51b607f78185ae5b3c88ecea1260032', class: `${this.rootClass}__content` }, hasSlot(this.el) ? (h("div", { class: `${this.rootClass}__body` }, h("slot", null))) : null, hasSlot(this.el, 'action') ? (h("div", { class: `${this.rootClass}__action` }, h("slot", { name: "action" }))) : null), this.closable && h("nj-icon-button", { key: '570276d2ba168941dbc4dda2ea09552ab5a31d76', class: `${this.rootClass}__close`, icon: "close", onClick: this.onCloseHandler, "aria-label": "close", as: "button" })));
    }
    static get is() { return "nj-inline-message"; }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InlineMessageProperties['variant']",
                    "resolved": "\"discovery\" | \"error\" | \"fatal-error\" | \"information\" | \"planet\" | \"success\" | \"warning\" | undefined",
                    "references": {
                        "InlineMessageProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::InlineMessageProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Semantic variations of the inline message."
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InlineMessageProperties['scale']",
                    "resolved": "\"md\" | \"sm\" | undefined",
                    "references": {
                        "InlineMessageProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::InlineMessageProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Scale of the inline message. Impacts the size of the text."
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "actionPosition": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InlineMessageProperties['actionPosition']",
                    "resolved": "\"bottom\" | \"right\" | undefined",
                    "references": {
                        "InlineMessageProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::InlineMessageProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Used to set the position of the action element."
                },
                "getter": false,
                "setter": false,
                "attribute": "action-position",
                "reflect": false
            },
            "hasStatus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "InlineMessageProperties['hasStatus']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "InlineMessageProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::InlineMessageProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the inline-message has a status indicator icon or not."
                },
                "getter": false,
                "setter": false,
                "attribute": "has-status",
                "reflect": false
            },
            "closable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "closable",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "onClose",
                "name": "nj-inline-message-close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=inline-message.js.map
