var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Fragment, h, Host } from "@stencil/core";
import { useId } from "../../utils/id";
import { extractHtmlInputProps } from "../../utils/properties.utils";
import { Slot } from "../../utils/slot";
/**
 * Inputs are used in forms to help people provide information. The following variations are available in Fluid:
 * Text
 * Password
 * Number
 *
 * Please be mindful of the overall accessibility of your forms by applying accessibility guidelines.
 *
 * @slot custom-icon - Custom icon element
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export class Input {
    constructor() {
        this.formItemClass = 'nj-form-item';
        this.passwordVisibleText = 'Password is visible';
        this.passwordHiddenText = 'Password is hidden';
        this.passwordShowActionAriaLabel = 'Show password';
        this.passwordHideActionAriaLabel = 'Hide password';
        this.isVisible = false;
    }
    get inputClasses() {
        return {
            [`${this.formItemClass}__field`]: true,
        };
    }
    get formItemClasses() {
        return {
            [this.formItemClass]: true,
            [`${this.formItemClass}--static`]: this.labelKind === 'static',
            [`${this.formItemClass}--${this.scale}`]: !!this.scale,
            [`${this.formItemClass}--disabled`]: !!this.disabled,
            [`${this.formItemClass}--invalid`]: !!this.invalid,
            [`${this.formItemClass}--password`]: this.type === 'password',
            [`${this.formItemClass}--visible`]: this.type === 'password' && this.isVisible,
        };
    }
    get subscriptClasses() {
        const subscriptBaseClass = `${this.formItemClass}__subscript`;
        return {
            [subscriptBaseClass]: true,
            [`${subscriptBaseClass}--${this.subscriptVariant}`]: !!this.subscriptVariant,
        };
    }
    get subscriptIcon() {
        switch (this.subscriptVariant) {
            case 'error':
                return h("nj-icon", { class: `${this.formItemClass}__subscript-icon`, name: "warning", variant: "red" });
            case 'success':
                return h("nj-icon", { class: `${this.formItemClass}__subscript-icon`, name: "check", variant: "green" });
            default:
                return null;
        }
    }
    /**
     * Toggles the visibility of a password field by switching its state between visible and hidden.
     */
    async togglePasswordVisibility() {
        this.isVisible = !this.isVisible;
    }
    updateValue(value) {
        this.internals.setFormValue(value);
    }
    connectedCallback() {
        var _a;
        this.internals.setFormValue((_a = this.value) !== null && _a !== void 0 ? _a : null);
    }
    render() {
        var _a, _b;
        (_a = this.customIcon) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.formItemClass}__custom-icon`);
        return (h(Host, { key: '90d2af04729bbfd8921b5c5f0a86584b67506320', class: this.formItemClasses }, h("div", { key: 'f6d00a87d4a8e9d798655e7993ff4a5320d0deab', class: `${this.formItemClass}__field-wrapper` }, h("input", Object.assign({ key: '35df6c48dbea39ad588743660cabbb27bc4f66b9', id: this.inputId }, extractHtmlInputProps(this), { type: this.type === 'password' && this.isVisible ? 'text' : this.type, onInput: this.handleChange.bind(this), class: this.inputClasses, placeholder: "" })), h("label", { key: '45d71673e99f5dfe90e067717a659b7ca2e5c41f', htmlFor: (_b = this.inputElement) === null || _b === void 0 ? void 0 : _b.id, class: `${this.formItemClass}__label` }, this.label, this.required && h("span", { key: 'b148f1ff030d2e932ab6379cc913e175894acd44', class: `${this.formItemClass}__required-asterisk` }, "*")), !this.customIcon && !this.icon && this.type === 'password' && (h(Fragment, { key: '2ad02f272bbb273d41bdbae81a0931a3b1b6a644' }, h("nj-icon-button", { key: 'f66fcab0c6d025cb4bacddd86c6fc92432294304', as: "button", type: "button", altLabel: this.isVisible ? this.passwordHideActionAriaLabel : this.passwordShowActionAriaLabel, pressed: this.isVisible, scale: "sm", icon: 'visibility', variant: "tertiary", class: `${this.formItemClass}__password-button`, onClick: this.togglePasswordVisibility.bind(this) }), h("p", { key: '695a11b02643eb816e746556a8ef345f08049934', class: "nj-sr-only", "aria-live": "polite", "aria-atomic": "true" }, this.isVisible ? this.passwordVisibleText : this.passwordHiddenText))), !this.customIcon && this.icon && h("nj-icon", { key: 'd0c16dc43030387413192394323ffe88168eb449', class: `${this.formItemClass}__icon`, name: this.icon }), h("slot", { key: 'e8ea990a0701854ab73708fc6969328553520efc', name: "custom-icon" })), this.subscript && (h("p", { key: 'f1635d635e9dda9ee3a0f6f6151a88f88835e13c', class: this.subscriptClasses, id: `${useId(this.inputId)}-subscript-message` }, this.subscriptIcon, this.subscript))));
    }
    handleChange(event) {
        const target = event.target;
        this.value = target.value;
    }
    static get is() { return "nj-input"; }
    static get formAssociated() { return true; }
    static get properties() {
        return {
            "inputId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['inputId']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The input id."
                },
                "getter": false,
                "setter": false,
                "attribute": "input-id",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['label']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The text label for the input field."
                },
                "getter": false,
                "setter": false,
                "attribute": "label",
                "reflect": false
            },
            "labelKind": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['labelKind']",
                    "resolved": "\"floating\" | \"static\" | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The kind of label to be displayed."
                },
                "getter": false,
                "setter": false,
                "attribute": "label-kind",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['scale']",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\" | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The size scale of the input."
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['icon']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Icon name to display alongside the input."
                },
                "getter": false,
                "setter": false,
                "attribute": "icon",
                "reflect": false
            },
            "invalid": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['invalid']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is in an invalid state."
                },
                "getter": false,
                "setter": false,
                "attribute": "invalid",
                "reflect": false
            },
            "subscript": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['subscript']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Additional text displayed below the input field."
                },
                "getter": false,
                "setter": false,
                "attribute": "subscript",
                "reflect": false
            },
            "subscriptVariant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['subscriptVariant']",
                    "resolved": "\"error\" | \"success\" | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Style variant for the subscript text."
                },
                "getter": false,
                "setter": false,
                "attribute": "subscript-variant",
                "reflect": false
            },
            "passwordVisibleText": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['passwordVisibleText']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Text to announce when password is visible."
                },
                "getter": false,
                "setter": false,
                "attribute": "password-visible-text",
                "reflect": false,
                "defaultValue": "'Password is visible'"
            },
            "passwordHiddenText": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['passwordHiddenText']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Text to announce when password is hidden."
                },
                "getter": false,
                "setter": false,
                "attribute": "password-hidden-text",
                "reflect": false,
                "defaultValue": "'Password is hidden'"
            },
            "passwordShowActionAriaLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['passwordShowActionAriaLabel']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Aria label for the show password action button."
                },
                "getter": false,
                "setter": false,
                "attribute": "password-show-action-aria-label",
                "reflect": false,
                "defaultValue": "'Show password'"
            },
            "passwordHideActionAriaLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['passwordHideActionAriaLabel']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Aria label for the hide password action button."
                },
                "getter": false,
                "setter": false,
                "attribute": "password-hide-action-aria-label",
                "reflect": false,
                "defaultValue": "'Hide password'"
            },
            "value": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "InputProps['value']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The input value"
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": true
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['type']",
                    "resolved": "string | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The input type (text, password, number, etc.)"
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false
            },
            "required": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['required']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is required"
                },
                "getter": false,
                "setter": false,
                "attribute": "required",
                "reflect": false
            },
            "readOnly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['readOnly']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is read-only"
                },
                "getter": false,
                "setter": false,
                "attribute": "read-only",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/input/input.tsx",
                            "id": "src/components/input/input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the input is disabled"
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isVisible": {}
        };
    }
    static get methods() {
        return {
            "togglePasswordVisibility": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "Toggles the visibility of a password field by switching its state between visible and hidden.",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "updateValue"
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    Slot('custom-icon')
], Input.prototype, "customIcon", void 0);
//# sourceMappingURL=input.js.map
