import { INPUT_SCALES, INPUT_LABEL_KIND, INPUT_SUBSCRIPT_VARIANT } from "@engie-group/fluid-types";
// Styles constants for better readability
const STYLES = {
    wrapper: 'display: flex; flex-wrap: wrap; gap: var(--nj-semantic-size-spacing-8); padding-left: 1rem;',
    inputContainer: 'display: flex; flex-direction: column; gap: var(--nj-semantic-size-spacing-8);',
};
const INPUT_VARIATIONS = ['disabled', 'readonly', 'invalid', 'required', 'icon', 'customIcon'];
const INPUT_TYPE = ['text', 'password', 'number'];
const getInputVariationAttributes = (variation) => {
    const attributes = [];
    if (variation === 'disabled')
        attributes.push('disabled');
    if (variation === 'readonly')
        attributes.push('read-only');
    if (variation === 'invalid')
        attributes.push('invalid');
    if (variation === 'required')
        attributes.push('required');
    if (variation === 'icon')
        attributes.push('icon="person"');
    switch (variation) {
        case 'icon':
            attributes.push('label="Input with icon"');
            break;
        case 'customIcon':
            attributes.push('label="Input with custom icon"');
            break;
        default:
            attributes.push(`label="Input ${variation}"`);
            break;
    }
    attributes.push('value="Value"');
    return attributes.join(' ');
};
const getInputContent = (variation) => {
    return variation === 'customIcon' ? '<nj-icon slot="custom-icon" name="person" variant="planet"></nj-icon> ' : '';
};
const getInputTypeAttributes = (type) => {
    const attributes = [`label="Input type ${type}"`, `type="${type}"`];
    const value = type === 'number' ? '23' : 'Value';
    attributes.push(`value="${value}"`);
    return attributes.join(' ');
};
export const fragment = `
<div style="${STYLES.wrapper}">
  <div>
    <h3>Input Variations</h3>
    <div style="${STYLES.inputContainer}">
      ${INPUT_VARIATIONS.map(variation => `
              <nj-input ${getInputVariationAttributes(variation)}>
                ${getInputContent(variation)}
              </nj-input>
            `).join('')}
    </div>
  </div>
  <div>
    <h3>Input types</h3>
    <div style="${STYLES.inputContainer}">
      ${INPUT_TYPE.map(type => `<nj-input ${getInputTypeAttributes(type)}></nj-input>`).join('')}
    </div>
  </div>
  <div>
    <h3>Input scales</h3>
    <div style="${STYLES.inputContainer}">
      ${INPUT_SCALES.map(scale => `<nj-input scale="${scale}" value="Value" label="Input scale ${scale}"></nj-input>`).join('')}
    </div>
  </div>
  <div>
    <h3>Input label kinds</h3>
    <div style="${STYLES.inputContainer}">
      ${INPUT_LABEL_KIND.map(labelKind => `
        <nj-input label-kind="${labelKind}" value="Value" label="Filled ${labelKind} label"></nj-input>
        <nj-input label-kind="${labelKind}" label="Empty ${labelKind} label"></nj-input>
      `).join('')}
    </div>
  </div>
  <div>
    <h3>Input subscript variants</h3>
    <div style="${STYLES.inputContainer}">
      ${[undefined, ...INPUT_SUBSCRIPT_VARIANT].map(subscriptVariant => `<nj-input subscript="Subscript" subscript-variant="${subscriptVariant}" value="Value" label="Label"></nj-input>`).join('')}
    </div>
  </div>
</div>
`;
//# sourceMappingURL=fragment.js.map
