import { h } from "@stencil/core";
import { hasSlot } from "../../utils/slot";
/**
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.0
 *
 * @slot leading - Slot for the leading element of the link
 * @slot trailing - Slot for the trailing element of the link
 *
 */
export class Link {
    get classes() {
        const hasLeadingSlot = hasSlot(this.el, 'leading');
        const hasTrailingSlot = hasSlot(this.el, 'trailing');
        return {
            'nj-link': true,
            'nj-link-icon': hasTrailingSlot || hasLeadingSlot,
            'nj-link-icon--before': hasLeadingSlot,
            [`nj-link--${this.variant}`]: !!this.variant,
            [`nj-link--${this.scale}`]: !!this.scale,
        };
    }
    render() {
        return (h("a", { key: '51e4470d9f329eac513d046fffb8188e90d2a2ad', class: this.classes, href: this.href, target: this.target, rel: this.rel, download: this.download }, h("slot", { key: 'db29f8f73e0dc5ef15b2f3606fb896e059e28c57', name: "leading" }), h("slot", { key: 'dcf7ab3f59dd41273480bc22a640490357f0b8d6' }), h("slot", { key: 'f483940feff643031e01d9042ba57d6f85dfc360', name: "trailing" })));
    }
    static get is() { return "nj-link"; }
    static get properties() {
        return {
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The URL that the hyperlink points to."
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The relationship between the current document and the linked document"
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Specifies where to open the linked document"
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "download": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "boolean | string",
                    "resolved": "boolean | string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Specifies whether the linked document will have a download option when clicked.\nIf a string is provided, it will be used as the filename."
                },
                "getter": false,
                "setter": false,
                "attribute": "download",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LinkProperties['variant']",
                    "resolved": "\"contextual\" | \"default\" | \"grayed\" | \"high-contrast\" | \"inverse\" | undefined",
                    "references": {
                        "LinkProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::LinkProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The variant theme"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LinkProperties['scale']",
                    "resolved": "\"md\" | \"sm\" | undefined",
                    "references": {
                        "LinkProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::LinkProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The scale of the link"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=link.js.map
