import { extractHtmlButtonProps, extractHtmlLinkProps } from "../../../utils/properties.utils";
import { listItemRender } from "../shared/list-item.utils";
/**
 * List item is a component designed to represent an item of a list.
 *
 * @slot leading - Leading slot
 * @slot trailing - Trailing slot
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export class ListNavigationItem {
    constructor() {
        this.rootClass = 'nj-list__navigation-item';
        this.listBaseClass = 'nj-list';
        this.as = 'span';
        this.render = () => listItemRender(this.listBaseClass, this.classes, this.el, this.wrapperProps, this);
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--vertical`]: this.textDistribution === 'vertical',
            [`${this.rootClass}--interactive`]: !!this.interactive,
        };
    }
    get wrapperProps() {
        if (this.as === 'a') {
            return extractHtmlLinkProps(this);
        }
        if (this.as === 'button') {
            return extractHtmlButtonProps(this);
        }
        return;
    }
    static get is() { return "nj-list-item"; }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['as']",
                    "resolved": "\"a\" | \"button\" | \"span\"",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The element tag to render"
                },
                "getter": false,
                "setter": false,
                "attribute": "as",
                "reflect": false,
                "defaultValue": "'span'"
            },
            "leadingIcon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['leadingIcon']",
                    "resolved": "string | undefined",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Leading icon name"
                },
                "getter": false,
                "setter": false,
                "attribute": "leading-icon",
                "reflect": false
            },
            "trailingIcon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['trailingIcon']",
                    "resolved": "string | undefined",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Trailing icon name"
                },
                "getter": false,
                "setter": false,
                "attribute": "trailing-icon",
                "reflect": false
            },
            "secondaryText": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['secondaryText']",
                    "resolved": "string | undefined",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "List item secondary text"
                },
                "getter": false,
                "setter": false,
                "attribute": "secondary-text",
                "reflect": false
            },
            "textDistribution": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['textDistribution']",
                    "resolved": "\"horizontal\" | \"vertical\" | undefined",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The text distribution of the list item.\nIf set to 'vertical', the secondary text will be displayed below the primary text."
                },
                "getter": false,
                "setter": false,
                "attribute": "text-distribution",
                "reflect": false
            },
            "interactive": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "ListItemProps['interactive']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "ListItemProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/list/list-item/list-item.tsx",
                            "id": "src/components/list/list-item/list-item.tsx::ListItemProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Force list item to be interactive without wrapper."
                },
                "getter": false,
                "setter": false,
                "attribute": "interactive",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['href']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['rel']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['target']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "download": {
                "type": "any",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['download']",
                    "resolved": "boolean | string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "download",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['type']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            },
            "form": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['form']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "form",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['name']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "name",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['value']",
                    "resolved": "string | undefined",
                    "references": {
                        "ButtonProps": {
                            "location": "import",
                            "path": "../../button/button",
                            "id": "src/components/button/button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "value",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=list-item.js.map
