var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { h, Host } from "@stencil/core";
import { extractHtmlButtonProps, extractHtmlLinkProps } from "../../utils/properties.utils";
import { Slot } from "../../utils/slot";
/**
 * NavigationAction component represents an action trigger in a navigation context, like header or footer components.
 *
 * @slot custom-icon - Navigation action custom icon
 * @slot custom-trailing - Navigation action custom trailing
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export class NavigationAction {
    constructor() {
        this.as = 'button';
        this.rootClass = 'nj-navigation-action';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
        };
    }
    get elementProps() {
        return this.as === 'a' ? extractHtmlLinkProps(this) : extractHtmlButtonProps(this);
    }
    get hasTextContent() {
        return Array.from(this.el.childNodes).filter(node => { var _a; return node.nodeType === Node.TEXT_NODE && ((_a = node.textContent) === null || _a === void 0 ? void 0 : _a.trim()); }).length > 0;
    }
    componentWillLoad() {
        var _a;
        (_a = this.customIcon) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.rootClass}__icon`);
    }
    render() {
        const Element = this.as;
        return (h(Host, { key: '8a9496be717ffe20ebdf1586ef2d4596f2c37cd5', class: this.classes, "aria-expanded": this.expanded }, h(Element, Object.assign({ key: '00c8ddb59ab207a1e46783af34fcf415560ccffb', class: `${this.rootClass}__action`, type: this.as === 'button' ? 'button' : undefined }, this.elementProps), this.icon && !this.customIcon && h("nj-icon", { key: '83c6e212fb439ecb8769d229ec98ff9afbc46683', class: `${this.rootClass}__icon`, name: this.icon }), h("slot", { key: '60589d8e77a51664a328aa23f432b1874a8a1708', name: "custom-icon" }), this.hasTextContent && (h("span", { key: '70f47150fde1a9479d93a2d3ec2ce5d12a756fab', class: `${this.rootClass}__content` }, h("slot", { key: '2a15cc0703f906374ad32f3b93502b87871b6d29' }))), h("slot", { key: 'fc575fc298369b796febfa04a7b7dd15a303ed16', name: "custom-trailing" }), this.expandable && h("nj-icon", { key: '77d927dbd0597a58fcd42d2e51d7bdedb7425d33', class: `${this.rootClass}__arrow`, name: "keyboard_arrow_down" }))));
    }
    static get is() { return "nj-navigation-action"; }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['as']",
                    "resolved": "\"a\" | \"button\"",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "as",
                "reflect": false,
                "defaultValue": "'button'"
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['icon']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "icon",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['variant']",
                    "resolved": "\"brand\" | \"discovery\" | \"inverse\" | \"primary\" | \"tertiary\" | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['scale']",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | \"xs\" | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "expandable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['expandable']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "expandable",
                "reflect": false
            },
            "expanded": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['expanded']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "expanded",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['href']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['rel']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['target']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationActionProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationActionProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-action/navigation-action.tsx",
                            "id": "src/components/navigation-action/navigation-action.tsx::NavigationActionProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
__decorate([
    Slot('custom-icon')
], NavigationAction.prototype, "customIcon", void 0);
__decorate([
    Slot('custom-trailing')
], NavigationAction.prototype, "customTrailing", void 0);
//# sourceMappingURL=navigation-action.js.map
