import { NAVIGATION_TAB_VARIANTS } from "@engie-group/fluid-types";
const STYLES = {
    wrapper: 'display: flex; flex-direction: column;',
    trailing: 'width: 32px; height: 32px; background-color: blue; border-radius: 50%;',
    groupContainer: 'padding: var(--nj-semantic-size-spacing-16) 0;',
    inverseGroupContainer: 'background-color: var(--nj-semantic-color-background-neutral-spotlight-default); padding: var(--nj-semantic-size-spacing-16) 0;',
    inverseTitle: 'color: var(--nj-semantic-color-icon-neutral-inverse-default);',
    actionsContainer: 'display: flex; gap: var(--nj-semantic-size-spacing-8)',
};
const NAVIGATION_ACTION_VARIATIONS = ['default', 'disabled', 'icon', 'customIcon', 'iconOnly', 'trailing', 'expandable', 'expanded'];
const getNavigationActionVariationAttributes = (variation, as, variant) => {
    const attributes = [`as="${as}"`];
    if (variation === 'disabled' && as === 'button')
        attributes.push('disabled');
    if (variation === 'icon')
        attributes.push('icon="home"');
    if (variation === 'iconOnly')
        attributes.push('icon="home"');
    if (variation === 'expandable')
        attributes.push('expandable');
    if (variation === 'expanded')
        attributes.push('expandable expanded');
    if (as === 'a') {
        attributes.push('href="#"');
    }
    if (variant) {
        attributes.push(`variant="${variant}`);
    }
    return attributes.join(' ');
};
const getNavigationActionContent = (variation) => {
    switch (variation) {
        case 'customIcon':
            return '<nj-icon slot="custom-icon" name="home" variant="planet"></nj-icon>Action with custom icon';
        case 'trailing':
            return `<span style="${STYLES.trailing}" slot="custom-trailing"></span>Action with custom trailing`;
        case 'default':
            return 'Default action';
        case 'disabled':
            return 'Disabled action';
        case 'icon':
            return 'Action with icon';
        case 'iconOnly':
            return '';
        case 'expandable':
            return 'Expandable action';
        case 'expanded':
            return 'Expanded action';
        default:
            return `Action ${variation}`;
    }
};
export const fragment = `
<div style="${STYLES.wrapper}">
  <div style="${STYLES.groupContainer}">
    <h3>Navigation action as button</h3>
      <div style="${STYLES.actionsContainer}">
      ${NAVIGATION_ACTION_VARIATIONS.map(variation => `
        <nj-navigation-action ${getNavigationActionVariationAttributes(variation, 'button')}>
          ${getNavigationActionContent(variation)}
        </nj-navigation-action>
      `).join('')}
      </div>
  </div>
  <div style="${STYLES.groupContainer}">
    <h3>Navigation action as link</h3>
    <div style="${STYLES.actionsContainer}">
      ${NAVIGATION_ACTION_VARIATIONS.filter(v => v !== 'disabled')
    .map(variation => `
        <nj-navigation-action ${getNavigationActionVariationAttributes(variation, 'a')}>
          ${getNavigationActionContent(variation)}
        </nj-navigation-action>
      `)
    .join('')}
    </div>
  </div>
  <div>
    <h3>Navigation tab variations</h3>
      ${NAVIGATION_TAB_VARIANTS.map(variant => `
        <div style="${variant === 'inverse' ? STYLES.inverseGroupContainer : STYLES.groupContainer}">
          <h4 style="${variant === 'inverse' ? STYLES.inverseTitle : ''}">Variant: ${variant}</h4>
          <div style="${STYLES.actionsContainer}">
            ${NAVIGATION_ACTION_VARIATIONS.map(variation => `
              <nj-navigation-action ${getNavigationActionVariationAttributes(variation, 'button', variant)}">
                ${getNavigationActionContent(variation)}
              </nj-navigation-action>
            `).join('')}
          </div>
        </div>
      `).join('')}
  </div>
</div>
`;
//# sourceMappingURL=fragment.js.map
