var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { h, Host } from "@stencil/core";
import { extractHtmlButtonProps, extractHtmlLinkProps } from "../../utils/properties.utils";
import { Slot } from "../../utils/slot";
/**
 * NavigationTab component is a tab that controls the content of a subsection. It's meant to be used in a navigation context
 * like a header, for example to control the display of an entire page.
 *
 * @slot custom-icon - Tab custom icon
 * @slot custom-trailing - Tab custom trailing
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export class NavigationTab {
    constructor() {
        this.as = 'button';
        this.rootClass = `nj-navigation-tab`;
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
        };
    }
    get elementProps() {
        return this.as === 'a' ? extractHtmlLinkProps(this) : extractHtmlButtonProps(this);
    }
    get hasTextContent() {
        return Array.from(this.el.childNodes).filter(node => { var _a; return node.nodeType === Node.TEXT_NODE && ((_a = node.textContent) === null || _a === void 0 ? void 0 : _a.trim()); }).length > 0;
    }
    componentWillLoad() {
        var _a;
        (_a = this.customIcon) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.rootClass}__icon`);
    }
    render() {
        const Element = this.as;
        return (h(Host, { key: 'a62d6564da55179e08f9ba489ac93d26642d13f7', class: this.classes, "aria-selected": this.selected, "aria-controls": this.controls, "aria-expanded": this.expanded, role: "tab" }, h(Element, Object.assign({ key: 'f21b6df6ba9ce488e6cd940f6233cefd9e4608a7', class: `${this.rootClass}__action`, type: this.as === 'button' ? 'button' : undefined }, this.elementProps), this.icon && !this.customIcon && h("nj-icon", { key: 'cfd0d3a52c38c80ea81a34f3107dbdaa739eb7f4', class: `${this.rootClass}__icon`, name: this.icon }), h("slot", { key: '5fa529e7b20e3e44eeca0ca17ea7b734c063a59e', name: "custom-icon" }), this.hasTextContent && (h("span", { key: '2e13a3bc2c71bd3c2356fa4f4e53e993fd22c53c', class: `${this.rootClass}__content` }, h("slot", { key: '7083be212fdf7d3073342babd5d432f5bf7eada0' }))), h("slot", { key: '82b6783278fbb4d54e7a9699f292819acbb9095b', name: "custom-trailing" }), this.expandable && h("nj-icon", { key: 'c0f912a93f47150625b541c8adfc19a07c679986', class: `${this.rootClass}__arrow`, name: "keyboard_arrow_down" }))));
    }
    static get is() { return "nj-navigation-tab"; }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['as']",
                    "resolved": "\"a\" | \"button\"",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The element tag to render"
                },
                "getter": false,
                "setter": false,
                "attribute": "as",
                "reflect": false,
                "defaultValue": "'button'"
            },
            "selected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['selected']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the tab item is selected."
                },
                "getter": false,
                "setter": false,
                "attribute": "selected",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['icon']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Leading icon name"
                },
                "getter": false,
                "setter": false,
                "attribute": "icon",
                "reflect": false
            },
            "controls": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['controls']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The id of the tab panel that the tab item controls."
                },
                "getter": false,
                "setter": false,
                "attribute": "controls",
                "reflect": false
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['variant']",
                    "resolved": "\"brand\" | \"discovery\" | \"inverse\" | \"primary\" | \"tertiary\" | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The color scheme variant of the tab."
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "expandable": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['expandable']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the tab is expandable."
                },
                "getter": false,
                "setter": false,
                "attribute": "expandable",
                "reflect": false
            },
            "expanded": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['expanded']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Whether the tab is expanded."
                },
                "getter": false,
                "setter": false,
                "attribute": "expanded",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['href']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "href",
                "reflect": false
            },
            "rel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['rel']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "rel",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['target']",
                    "resolved": "string | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "target",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "NavigationTabProps['disabled']",
                    "resolved": "boolean | undefined",
                    "references": {
                        "NavigationTabProps": {
                            "location": "local",
                            "path": "/home/runner/_work/fluid-design-system/fluid-design-system/packages/fluid-webcomponents/src/components/navigation-tab/navigation-tab.tsx",
                            "id": "src/components/navigation-tab/navigation-tab.tsx::NavigationTabProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
__decorate([
    Slot('custom-icon')
], NavigationTab.prototype, "customIcon", void 0);
__decorate([
    Slot('custom-trailing')
], NavigationTab.prototype, "customTrailing", void 0);
//# sourceMappingURL=navigation-tab.js.map
