import { NAVIGATION_TAB_VARIANTS } from "@engie-group/fluid-types";
const STYLES = {
    wrapper: 'display: flex; flex-direction: column;',
    trailing: 'width: 32px; height: 32px; background-color: blue; border-radius: 50%;',
    tabsContainer: 'padding: var(--nj-semantic-size-spacing-16) 0;',
    inverseContainer: 'background-color: var(--nj-semantic-color-background-neutral-spotlight-default); padding: var(--nj-semantic-size-spacing-16) 0;',
    inverseTitle: 'color: var(--nj-semantic-color-icon-neutral-inverse-default);',
};
const NAVIGATION_TAB_VARIATIONS = ['default', 'selected', 'disabled', 'icon', 'customIcon', 'trailing', 'expandable', 'expanded'];
const getNavigationTabVariationAttributes = (variation, as, variant) => {
    const attributes = [`as="${as}"`];
    if (variation === 'selected')
        attributes.push('selected');
    if (variation === 'disabled' && as === 'button')
        attributes.push('disabled');
    if (variation === 'icon')
        attributes.push('icon="home"');
    if (variation === 'expandable')
        attributes.push('expandable');
    if (variation === 'expanded')
        attributes.push('expandable expanded');
    if (as === 'a') {
        attributes.push('href="#"');
    }
    if (variant) {
        attributes.push(`variant="${variant}`);
    }
    return attributes.join(' ');
};
const getNavigationTabContent = (variation) => {
    switch (variation) {
        case 'customIcon':
            return '<nj-icon slot="custom-icon" name="home" variant="planet"></nj-icon>Tab with custom icon';
        case 'trailing':
            return `<span style="${STYLES.trailing}" slot="custom-trailing"></span>Tab with custom trailing`;
        case 'default':
            return 'Default tab';
        case 'selected':
            return 'Selected tab';
        case 'disabled':
            return 'Disabled tab';
        case 'icon':
            return 'Tab with icon';
        case 'expandable':
            return 'Expandable tab';
        case 'expanded':
            return 'Expanded tab';
        default:
            return `Tab ${variation}`;
    }
};
export const fragment = `
<div style="${STYLES.wrapper}">
  <div style="${STYLES.tabsContainer}">
    <h3>Navigation tab as button</h3>
      <div class="nj-tabs">
      ${NAVIGATION_TAB_VARIATIONS.map(variation => `
        <nj-navigation-tab ${getNavigationTabVariationAttributes(variation, 'button')}>
          ${getNavigationTabContent(variation)}
        </nj-navigation-tab>
      `).join('')}
      </div>
  </div>
  <div style="${STYLES.tabsContainer}">
    <h3>Navigation tab as link</h3>
    <div class="nj-tabs">
      ${NAVIGATION_TAB_VARIATIONS.filter(v => v !== 'disabled')
    .map(variation => `
        <nj-navigation-tab ${getNavigationTabVariationAttributes(variation, 'a')}>
          ${getNavigationTabContent(variation)}
        </nj-navigation-tab>
      `)
    .join('')}
    </div>
  </div>
  <div>
    <h3>Navigation tab variations</h3>
      ${NAVIGATION_TAB_VARIANTS.map(variant => `
        <div style="${variant === 'inverse' ? STYLES.inverseContainer : STYLES.tabsContainer}">
          <h4 style="${variant === 'inverse' ? STYLES.inverseTitle : ''}">Variant: ${variant}</h4>
          <div class="nj-tabs">
            ${NAVIGATION_TAB_VARIATIONS.filter(v => v !== 'disabled')
    .map(variation => `
              <nj-navigation-tab ${getNavigationTabVariationAttributes(variation, 'button', variant)}">
                ${getNavigationTabContent(variation)}
              </nj-navigation-tab>
            `)
    .join('')}
          </div>
        </div>
      `).join('')}
  </div>
</div>
`;
//# sourceMappingURL=fragment.js.map
