import { h, Host } from "@stencil/core";
/**
 * Spinner allows the user to know when the system is in progress and when he will end. The spinner is used to indicate the current status of a loading screen or a loading data.
 *
 * @since 0.1.0-next.1
 * @lastmodified 0.1.0-next.1
 */
export class Spinner {
    constructor() {
        this.rootClass = 'nj-spinner';
        /**
         * Aria label, for accessibility reasons
         */
        this.ariaLabel = 'loading';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.variant}`]: !!this.variant,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
        };
    }
    render() {
        return h(Host, { key: 'b28fb11b17fcde77fc4ae15f9f72502fb38cd53d', class: this.classes, "aria-label": this.ariaLabel });
    }
    static get is() { return "nj-spinner"; }
    static get properties() {
        return {
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "SpinnerProperties['variant']",
                    "resolved": "\"ai\" | \"grey\" | \"inverse\" | \"normal\" | undefined",
                    "references": {
                        "SpinnerProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::SpinnerProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Spinner color variant"
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "SpinnerProperties['scale']",
                    "resolved": "\"2xs\" | \"lg\" | \"md\" | \"sm\" | \"xs\" | undefined",
                    "references": {
                        "SpinnerProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::SpinnerProperties"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Spinner scale"
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            },
            "ariaLabel": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "ARIAMixin['ariaLabel']",
                    "resolved": "null | string",
                    "references": {
                        "ARIAMixin": {
                            "location": "global",
                            "id": "global::ARIAMixin"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Aria label, for accessibility reasons"
                },
                "getter": false,
                "setter": false,
                "attribute": "aria-label",
                "reflect": false,
                "defaultValue": "'loading'"
            }
        };
    }
}
//# sourceMappingURL=spinner.js.map
