import { h, Host } from "@stencil/core";
/**
 * Status indicators are dynamic pieces of information that should be used to convey the status of a person, an object or a process.
 * They do not require any user actions to be updated, and are usually part of a larger component.
 *
 * @since 0.1.0-next.0
 * @lastmodified 0.1.0-next.0
 */
export class StatusIndicator {
    constructor() {
        this.rootClass = 'nj-status-indicator';
    }
    get classes() {
        return {
            [this.rootClass]: true,
            [`${this.rootClass}--${this.status}`]: !!this.status,
            [`${this.rootClass}--${this.scale}`]: !!this.scale,
        };
    }
    componentWillRender() {
        this.contentNodes = Array.from(this.el.childNodes).filter(node => node.nodeType !== 8); // filter out comment nodes
    }
    render() {
        return (h(Host, { key: '6ae18aa809fb8f2562ff4438941052bc5e590a43', class: this.classes }, h("div", { key: 'fce04e109882b4c87c0619e1684e53045e5c6a4c', class: `${this.rootClass}__svg` }), this.contentNodes.length > 0 ? (h("div", { class: `${this.rootClass}__text` }, h("slot", null))) : null));
    }
    static get is() { return "nj-status-indicator"; }
    static get styles() { return "nj-status-indicator {\n      display: contents;\n    }"; }
    static get properties() {
        return {
            "status": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "StatusIndicatorProperties['status']",
                    "resolved": "\"ai\" | \"away\" | \"busy\" | \"discovery\" | \"do-not-disturb\" | \"error\" | \"in-progress\" | \"information\" | \"offline\" | \"online\" | \"planet\" | \"success\" | \"unknown\" | \"warning\" | undefined",
                    "references": {
                        "StatusIndicatorProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::StatusIndicatorProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The status of the indicator."
                },
                "getter": false,
                "setter": false,
                "attribute": "status",
                "reflect": false
            },
            "scale": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "StatusIndicatorProperties['scale']",
                    "resolved": "\"lg\" | \"md\" | \"sm\" | undefined",
                    "references": {
                        "StatusIndicatorProperties": {
                            "location": "import",
                            "path": "@engie-group/fluid-types",
                            "id": "../types/dist/index.d.ts::StatusIndicatorProperties"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The scale of the indicator."
                },
                "getter": false,
                "setter": false,
                "attribute": "scale",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=status-indicator.js.map
