import { r as registerInstance, h, H as Host, g as getElement } from './index-ea5ff4dd.js';
import { S as Slot } from './slot-72d34576.js';

const Footer = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.RESPONSIVE_CSS_VAR = '--nj-footer-responsive-mode';
        this.handleResize = () => {
            if (this.resizeTimeout) {
                clearTimeout(this.resizeTimeout);
            }
            this.resizeTimeout = setTimeout(() => this.updateMode(), 200);
        };
    }
    get classes() {
        return {
            'nj-footer': true,
            [`nj-footer--${this.variant}`]: !!this.variant && this.variant !== 'neutral',
            'nj-footer--mobile': this.responsiveMode === 'mobile',
        };
    }
    getCssVariable(varName) {
        return getComputedStyle(document.documentElement).getPropertyValue(varName).trim().replace(/"/g, '');
    }
    updateMode() {
        const newMode = this.getCssVariable(this.RESPONSIVE_CSS_VAR);
        if (newMode !== this.responsiveMode) {
            this.responsiveMode = newMode;
        }
    }
    componentWillLoad() {
        this.updateMode();
        window.addEventListener('resize', this.handleResize);
    }
    disconnectedCallback() {
        window.removeEventListener('resize', this.handleResize);
        if (this.resizeTimeout) {
            clearTimeout(this.resizeTimeout);
        }
    }
    render() {
        return (h("div", { key: '12c689256152ef5b70b7d15764b46eb5811eef7b', class: this.classes }, h("slot", { key: '0cf63a401f9e957c41d9e783dedbcc0afa355f68' })));
    }
};

const FooterContent$2 = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    get classes() {
        return {
            'nj-footer-card': true,
            [`nj-footer-card--${this.variant}`]: !!this.variant,
        };
    }
    render() {
        return (h(Host, { key: 'f2034609c71e9564d3c92db48023bae0a0b16608', class: this.classes }, h("slot", { key: '1ecf4ff44c9a4650f25811da19686321f23f632f' })));
    }
};
FooterContent$2.style = "nj-footer-card { display: block }";

const FooterColumn = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    get classes() {
        return {
            'nj-footer-column': true,
        };
    }
    render() {
        return (h(Host, { key: '43b59ee1684a7340d463fb56dd4a435f5567d37e', class: this.classes }, h("div", { key: '037fc0b1593cdf07fa548e5017f610208b8c3ebd', class: "nj-footer-column__header" }, h("slot", { key: 'c15b0f86f99f29976b59d10a5924e61254902086', name: "header" })), h("slot", { key: '0bb507cd70dec4796d1b82153cf041d5196b35df' })));
    }
};

const FooterContent$1 = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h("footer", { key: 'aae68f953769c6fc715def404ffa4fad4aab2261', class: "nj-footer-content" }, h("slot", { key: '4e1f0f7e86fe5fcbda5439cc948a3520270839a3' })));
    }
};
FooterContent$1.style = "nj-footer-content { display: contents }";

const FooterContent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h(Host, { key: '39d4055bbd71142dc8c81d1ec4549ac754f7dece', class: "nj-footer-content-top" }, h("div", { key: 'e789ab0ec67427851eb300ed1d42182ac166618a', class: "nj-footer-content-top__logo-wrapper" }, h("slot", { key: 'd3865aefb990ddc55ce66276c4113a9cf76f34b9', name: "logo" }), h("slot", { key: '55d9fb1ac4e451f2c78b33e8c2c02237f33eccae', name: "baseline" })), h("slot", { key: '559d6aad19b52f83144bb93a22398b2416da568f' })));
    }
};

const FooterItem = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    get classes() {
        return {
            'nj-footer-item': true,
            [`nj-footer-item--padding-${this.padding}`]: !!this.padding,
        };
    }
    render() {
        return (h("nj-link", { key: 'f865e4181718ae8499cbf6b4c1c4f3cfeeb1adb9', class: this.classes, rel: this.rel, target: this.target, href: this.href, download: this.download, scale: this.scale, variant: "contextual" }, h("slot", { key: '5456d9d42bdcf08042e437dd4ad6eecc66e38c57', name: "leading" }), h("slot", { key: '89e9c55058b8b97509511ccb01c4f4e18791657d' }), h("slot", { key: '86d5a82f80ccce3c2a537898d0915f7899a96337', name: "trailing" })));
    }
};
FooterItem.style = "nj-footer-item { display: contents }";

const FooterNavigation = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h(Host, { key: '981749fb9b3d9b6304f1f8c36e692172b8e36862', class: "nj-footer-navigation" }, h("slot", { key: '824ec0cae3e67cb67461e8be9bf93e0fd1a4fd4e' })));
    }
};

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const FooterSecondaryNavigation = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.rootClass = 'nj-footer-secondary-navigation';
    }
    addClasses() {
        var _a, _b;
        (_a = this.controls) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.rootClass}__controls`);
        (_b = this.links) === null || _b === void 0 ? void 0 : _b.classList.add(`${this.rootClass}__links`);
    }
    render() {
        return (h(Host, { key: '75f889cf46b821359244c91d6305fcb31178937c', class: this.rootClass }, h("slot", { key: '97c1eead21b0b3e5dea4d11b16b71ce954999a4a', name: "controls" }), h("slot", { key: '5d3b007663d3f1f209f7c2c978a6fa5608692ed3', name: "links" }), h("div", { key: '7bbcc8f573e9d608eccc1d73ecabd14224625528', class: `${this.rootClass}__copyright` }, this.copyright)));
    }
    componentDidRender() {
        this.addClasses();
    }
    get el() { return getElement(this); }
};
__decorate([
    Slot('controls')
], FooterSecondaryNavigation.prototype, "controls", void 0);
__decorate([
    Slot('links')
], FooterSecondaryNavigation.prototype, "links", void 0);

export { Footer as nj_footer, FooterContent$2 as nj_footer_card, FooterColumn as nj_footer_column, FooterContent$1 as nj_footer_content, FooterContent as nj_footer_content_top, FooterItem as nj_footer_item, FooterNavigation as nj_footer_navigation, FooterSecondaryNavigation as nj_footer_secondary_navigation };

//# sourceMappingURL=nj-footer_8.entry.js.map