import { r as registerInstance, h, F as Fragment, H as Host, g as getElement } from './index-ea5ff4dd.js';
import { u as useId } from './id-73b21082.js';
import { b as extractHtmlInputProps } from './properties.utils-81ed4256.js';
import { S as Slot } from './slot-72d34576.js';

var __decorate = (undefined && undefined.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
const Input = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        if (hostRef.$hostElement$["s-ei"]) {
            this.internals = hostRef.$hostElement$["s-ei"];
        }
        else {
            this.internals = hostRef.$hostElement$.attachInternals();
            hostRef.$hostElement$["s-ei"] = this.internals;
        }
        this.formItemClass = 'nj-form-item';
        this.passwordVisibleText = 'Password is visible';
        this.passwordHiddenText = 'Password is hidden';
        this.passwordShowActionAriaLabel = 'Show password';
        this.passwordHideActionAriaLabel = 'Hide password';
        this.isVisible = false;
    }
    get inputClasses() {
        return {
            [`${this.formItemClass}__field`]: true,
        };
    }
    get formItemClasses() {
        return {
            [this.formItemClass]: true,
            [`${this.formItemClass}--static`]: this.labelKind === 'static',
            [`${this.formItemClass}--${this.scale}`]: !!this.scale,
            [`${this.formItemClass}--disabled`]: !!this.disabled,
            [`${this.formItemClass}--invalid`]: !!this.invalid,
            [`${this.formItemClass}--password`]: this.type === 'password',
            [`${this.formItemClass}--visible`]: this.type === 'password' && this.isVisible,
        };
    }
    get subscriptClasses() {
        const subscriptBaseClass = `${this.formItemClass}__subscript`;
        return {
            [subscriptBaseClass]: true,
            [`${subscriptBaseClass}--${this.subscriptVariant}`]: !!this.subscriptVariant,
        };
    }
    get subscriptIcon() {
        switch (this.subscriptVariant) {
            case 'error':
                return h("nj-icon", { class: `${this.formItemClass}__subscript-icon`, name: "warning", variant: "red" });
            case 'success':
                return h("nj-icon", { class: `${this.formItemClass}__subscript-icon`, name: "check", variant: "green" });
            default:
                return null;
        }
    }
    /**
     * Toggles the visibility of a password field by switching its state between visible and hidden.
     */
    async togglePasswordVisibility() {
        this.isVisible = !this.isVisible;
    }
    updateValue(value) {
        this.internals.setFormValue(value);
    }
    connectedCallback() {
        var _a;
        this.internals.setFormValue((_a = this.value) !== null && _a !== void 0 ? _a : null);
    }
    render() {
        var _a, _b;
        (_a = this.customIcon) === null || _a === void 0 ? void 0 : _a.classList.add(`${this.formItemClass}__custom-icon`);
        return (h(Host, { key: '90d2af04729bbfd8921b5c5f0a86584b67506320', class: this.formItemClasses }, h("div", { key: 'f6d00a87d4a8e9d798655e7993ff4a5320d0deab', class: `${this.formItemClass}__field-wrapper` }, h("input", Object.assign({ key: '35df6c48dbea39ad588743660cabbb27bc4f66b9', id: this.inputId }, extractHtmlInputProps(this), { type: this.type === 'password' && this.isVisible ? 'text' : this.type, onInput: this.handleChange.bind(this), class: this.inputClasses, placeholder: "" })), h("label", { key: '45d71673e99f5dfe90e067717a659b7ca2e5c41f', htmlFor: (_b = this.inputElement) === null || _b === void 0 ? void 0 : _b.id, class: `${this.formItemClass}__label` }, this.label, this.required && h("span", { key: 'b148f1ff030d2e932ab6379cc913e175894acd44', class: `${this.formItemClass}__required-asterisk` }, "*")), !this.customIcon && !this.icon && this.type === 'password' && (h(Fragment, { key: '2ad02f272bbb273d41bdbae81a0931a3b1b6a644' }, h("nj-icon-button", { key: 'f66fcab0c6d025cb4bacddd86c6fc92432294304', as: "button", type: "button", altLabel: this.isVisible ? this.passwordHideActionAriaLabel : this.passwordShowActionAriaLabel, pressed: this.isVisible, scale: "sm", icon: 'visibility', variant: "tertiary", class: `${this.formItemClass}__password-button`, onClick: this.togglePasswordVisibility.bind(this) }), h("p", { key: '695a11b02643eb816e746556a8ef345f08049934', class: "nj-sr-only", "aria-live": "polite", "aria-atomic": "true" }, this.isVisible ? this.passwordVisibleText : this.passwordHiddenText))), !this.customIcon && this.icon && h("nj-icon", { key: 'd0c16dc43030387413192394323ffe88168eb449', class: `${this.formItemClass}__icon`, name: this.icon }), h("slot", { key: 'e8ea990a0701854ab73708fc6969328553520efc', name: "custom-icon" })), this.subscript && (h("p", { key: 'f1635d635e9dda9ee3a0f6f6151a88f88835e13c', class: this.subscriptClasses, id: `${useId(this.inputId)}-subscript-message` }, this.subscriptIcon, this.subscript))));
    }
    handleChange(event) {
        const target = event.target;
        this.value = target.value;
    }
    static get formAssociated() { return true; }
    get el() { return getElement(this); }
    static get watchers() { return {
        "value": ["updateValue"]
    }; }
};
__decorate([
    Slot('custom-icon')
], Input.prototype, "customIcon", void 0);

export { Input as nj_input };

//# sourceMappingURL=nj-input.entry.js.map