/**
 * Extracts specific properties related to HTML link elements from the given object.
 *
 * This function takes an object containing potential HTML link element properties
 * and returns a new object with only the selected properties, example : `href`, `rel`, `target`, and `download`.
 *
 * @param {HtmlLinkProperties} obj - The object containing HTML link element properties.
 * @returns {HtmlLinkProperties} A new object containing the extracted properties.
 */
const extractHtmlLinkProps = (obj) => ({
    href: obj.href,
    rel: obj.rel,
    target: obj.target,
    download: obj.download,
});
/**
 * Extracts specific HTML button properties from the given object and returns a new object
 * containing only the extracted properties. This function ensures that only relevant button
 * properties are included in the resulting object.
 *
 * @param {HtmlButtonProperties} obj - The source object containing HTML button properties.
 * @returns {HtmlButtonProperties} A new object containing the extracted HTML button properties.
 */
const extractHtmlButtonProps = (obj) => ({
    type: obj.type,
    disabled: obj.disabled,
    form: obj.form,
    name: obj.name,
    value: obj.value,
});
/**
 * Extracts specific HTML input properties from the given object and returns a new object
 * containing only the extracted properties. This function ensures that only relevant input
 * properties are included in the resulting object.
 *
 * @param {InputHTMLAttributes<HTMLInputElement>} obj - The source object containing HTML input properties.
 * @returns {InputHTMLAttributes<HTMLInputElement>} A new object containing the extracted HTML input properties.
 */
const extractHtmlInputProps = (obj) => ({
    type: obj.type,
    value: obj.value,
    required: obj.required,
    readOnly: obj.readOnly,
    disabled: obj.disabled,
});

export { extractHtmlButtonProps as a, extractHtmlInputProps as b, extractHtmlLinkProps as e };

//# sourceMappingURL=properties.utils-81ed4256.js.map