import { JsonDocsComponent } from '../../../../../../../../../../stencil-public-runtime';
type MetaTemplateVariables = {
    parameters: object;
    argTypes: object;
};
type StoryTemplateVariables = {
    className: string;
    component: string;
    storyTitle: string;
    tag: string;
};
type FollowUpTemplateVariables = {
    storyStatus: object;
};
export declare function registerHandlebarsHelpers(): void;
/**
 * Asynchronously checks if a story file exists for the given component.
 *
 * @param {JsonDocsComponent} component - The component object containing information used to determine the file path.
 * @return {Promise<boolean>} A promise that resolves to true if the file exists, or false if it does not.
 */
export declare function checkStoryFile(component: JsonDocsComponent): Promise<boolean>;
/**
 * Generates meta information content for component.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export declare function generateMetaContent(templateVariables: MetaTemplateVariables): Promise<string>;
/**
 * Generates content of the story file.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export declare function generateStoryContent(templateVariables: StoryTemplateVariables): Promise<string>;
/**
 * Generates content of the follow-up file.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export declare function generateFollowUpContent(templateVariables: FollowUpTemplateVariables): Promise<string>;
/**
 * Writes the provided content to a story file for the given component.
 *
 * @param {JsonDocsComponent} component - The component we need to write file for.
 * @param {string} content - The content to be written into the story file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export declare function writeStoryFile(component: JsonDocsComponent, content: string): Promise<void>;
/**
 * Writes the provided content to a meta file for the given component.
 *
 * @param {JsonDocsComponent} component - The component we need to write file for.
 * @param {string} content - The content to be written into the meta file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export declare function writeMetaFile(component: JsonDocsComponent, content: string): Promise<void>;
/**
 * Writes the provided content to the follow-up file.
 *
 * @param {string} content - The content to be written into the follow-up file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export declare function writeFollowUpFile(content: string): Promise<void>;
export {};
