import { CheckboxProperties } from '@engie-group/fluid-types';
import { EventEmitter } from '../../stencil-public-runtime';
/**
 * A checkbox is an input control that allows the user to give a feedback by choosing several items from a list of options.
 *
 * @since 0.1.0-next.1
 * @lastmodified 0.1.0-next.1
 */
export declare class Checkbox implements CheckboxProperties {
    private readonly rootClass;
    element: HTMLElement;
    /**
     * Represents the identifier for the input element.
     * This optional variable allows you to specify a unique identifier
     * for referencing or interacting with the input element.
     *
     * @type {string}
     */
    inputId?: string;
    /**
     * Name of the form control. Submitted with the form as part of a name/value pair
     */
    name?: string;
    /**
     * The value of the checkbox when checked.
     */
    value?: string;
    scale?: CheckboxProperties['scale'];
    subscript?: CheckboxProperties['subscript'];
    subscriptVariant?: CheckboxProperties['subscriptVariant'];
    checked: CheckboxProperties['disabled'];
    required: CheckboxProperties['disabled'];
    indeterminate: CheckboxProperties['indeterminate'];
    disabled: CheckboxProperties['disabled'];
    invalid: CheckboxProperties['invalid'];
    /**
     * Emits a boolean value indicating the change in the "checked" state.
     */
    checkedChange: EventEmitter<boolean>;
    /**
     * Emits an event whenever the indeterminate state of the checkbox changes.
     */
    indeterminateChange: EventEmitter<boolean>;
    private handleChange;
    private get classes();
    render(): any;
    componentDidRender(): void;
}
