import { InputProperties } from '@engie-group/fluid-types';
import { JSXBase } from '../../stencil-public-runtime';
import InputHTMLAttributes = JSXBase.InputHTMLAttributes;
export type InputProps = InputProperties & Omit<InputHTMLAttributes<HTMLInputElement>, 'value' | 'placeholder'> & {
    /**
     * The input id.
     */
    inputId?: string;
    /**
     * The input value
     */
    value: Exclude<InputHTMLAttributes<HTMLInputElement>['value'], number | string[]>;
};
/**
 * Inputs are used in forms to help people provide information. The following variations are available in Fluid:
 * Text
 * Password
 * Number
 *
 * Please be mindful of the overall accessibility of your forms by applying accessibility guidelines.
 *
 * @slot custom-icon - Custom icon element
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export declare class Input implements InputProps {
    private readonly formItemClass;
    private inputElement?;
    inputId: InputProps['inputId'];
    label: InputProps['label'];
    labelKind: InputProps['labelKind'];
    scale: InputProps['scale'];
    icon: InputProps['icon'];
    invalid: InputProps['invalid'];
    subscript: InputProps['subscript'];
    subscriptVariant: InputProps['subscriptVariant'];
    passwordVisibleText: InputProps['passwordVisibleText'];
    passwordHiddenText: InputProps['passwordHiddenText'];
    passwordShowActionAriaLabel: InputProps['passwordShowActionAriaLabel'];
    passwordHideActionAriaLabel: InputProps['passwordHideActionAriaLabel'];
    value: InputProps['value'];
    /**
     * The input type (text, password, number, etc.)
     */
    type: InputProps['type'];
    /**
     * Whether the input is required
     */
    required: InputProps['required'];
    /**
     * Whether the input is read-only
     */
    readOnly: InputProps['readOnly'];
    /**
     * Whether the input is disabled
     */
    disabled: InputProps['disabled'];
    private isVisible;
    private internals;
    el: HTMLElement;
    customIcon: HTMLElement;
    private get inputClasses();
    private get formItemClasses();
    private get subscriptClasses();
    private get subscriptIcon();
    /**
     * Toggles the visibility of a password field by switching its state between visible and hidden.
     */
    togglePasswordVisibility(): Promise<void>;
    updateValue(value: string): void;
    connectedCallback(): void;
    render(): any;
    private handleChange;
}
