import { ListNavigationItemProperties } from '@engie-group/fluid-types';
import { As } from '../../../types/as.type';
import { HtmlButtonProperties } from '../../../types/html-button.properties';
import { HtmlLinkProperties } from '../../../types/html-link.properties';
import { ButtonProps } from '../../button/button';
export type ListNavigationItemProps = ListNavigationItemProperties & HtmlButtonProperties & HtmlLinkProperties & As<'a' | 'button' | 'span'>;
/**
 * List navigation item is a component designed to represent a navigation item of a list.
 *
 * It works the same as a List item but with some specific added features and states like `expandable` mode and `expanded` state.
 * It can also be in different color scheme like `discovery`.
 *
 * @slot leading - Leading slot
 * @slot trailing - Trailing slot
 *
 * @since 0.1.0-next.3
 * @lastmodified 0.1.0-next.3
 */
export declare class ListNavigationItem implements ListNavigationItemProps {
    private readonly rootClass;
    private readonly listBaseClass;
    as: ListNavigationItemProps['as'];
    leadingIcon: ListNavigationItemProps['leadingIcon'];
    trailingIcon: ListNavigationItemProps['trailingIcon'];
    secondaryText: ListNavigationItemProps['secondaryText'];
    expandable: ListNavigationItemProps['expandable'];
    expanded: ListNavigationItemProps['expanded'];
    variant: ListNavigationItemProps['variant'];
    textDistribution: ListNavigationItemProps['textDistribution'];
    selected: ListNavigationItemProps['selected'];
    interactive: ListNavigationItemProps['interactive'];
    href: ButtonProps['href'];
    rel: ButtonProps['rel'];
    target: ButtonProps['target'];
    download: ButtonProps['download'];
    type: ButtonProps['type'];
    disabled: ButtonProps['disabled'];
    form: ButtonProps['form'];
    name: ButtonProps['name'];
    value: ButtonProps['value'];
    el: HTMLElement;
    private get classes();
    private get wrapperProps();
    render: () => any;
}
