import { HtmlButtonProperties } from '../types/html-button.properties';
import { HtmlLinkProperties } from '../types/html-link.properties';
import { JSXBase } from '../stencil-public-runtime';
import InputHTMLAttributes = JSXBase.InputHTMLAttributes;
/**
 * Extracts specific properties related to HTML link elements from the given object.
 *
 * This function takes an object containing potential HTML link element properties
 * and returns a new object with only the selected properties, example : `href`, `rel`, `target`, and `download`.
 *
 * @param {HtmlLinkProperties} obj - The object containing HTML link element properties.
 * @returns {HtmlLinkProperties} A new object containing the extracted properties.
 */
export declare const extractHtmlLinkProps: (obj: HtmlLinkProperties) => HtmlLinkProperties;
/**
 * Extracts specific HTML button properties from the given object and returns a new object
 * containing only the extracted properties. This function ensures that only relevant button
 * properties are included in the resulting object.
 *
 * @param {HtmlButtonProperties} obj - The source object containing HTML button properties.
 * @returns {HtmlButtonProperties} A new object containing the extracted HTML button properties.
 */
export declare const extractHtmlButtonProps: (obj: HtmlButtonProperties) => HtmlButtonProperties;
/**
 * Extracts specific HTML input properties from the given object and returns a new object
 * containing only the extracted properties. This function ensures that only relevant input
 * properties are included in the resulting object.
 *
 * @param {InputHTMLAttributes<HTMLInputElement>} obj - The source object containing HTML input properties.
 * @returns {InputHTMLAttributes<HTMLInputElement>} A new object containing the extracted HTML input properties.
 */
export declare const extractHtmlInputProps: (obj: InputHTMLAttributes<HTMLInputElement>) => InputHTMLAttributes<HTMLInputElement>;
